'use strict';
// 変数スライダー
// 実数をインプットするためのスライダー
// 呼び方 var a=new VarSlider("変数スライダー表示領域のid",最小値,最大値,現在値,ステップ,変更された時に呼び出す関数,ラベル);
// 例：
// <p><span id="g">重力加速度gを表示する領域</span></p>
//	<script>
//	 var gsl=new VarSlider("g",-10,10,1,0.1,function (x) { ps.gravity=x;},"重力加速度");
//	</script>
// 実行されると、<span id="g">重力加速度gを表示する領域</span>の部分が
// <span id="g_value_string">重力加速度=1</span><input type="range" id="g_slider">
// に書き換えられる（どうせ書き換えられるので、最初の文字列は空文でも可）。
// 最後の引数である「変更された時に呼び出す関数」は、上のように無名関数を記入してもよいし、他のところで定義した
// 関数の名前を書いてもよい。関数の引数には、スライダーの現在の値が入って呼び出される。
var VarSlider = function (id_string, min, max, value, step, func, name_string) {
	if (name_string === undefined) {
		name_string = id_string;
	}
	document.getElementById(id_string).innerHTML = '<span id="' + id_string + '_value_string"></span><input type="range" id="' + id_string + '_slider">';
	this.sliderid = id_string + "_slider";
	this.labelstring = name_string + "=";
	this.valuestring = document.getElementById(id_string + "_value_string");
	this.slider = document.getElementById(this.sliderid);

	if (min !== undefined) {
		this.slider.min = min;
	}
	if (max !== undefined) {
		this.slider.max = max;
	}
	if (step !== undefined) {
		this.slider.step = step;
	}
	if (value !== undefined) {
		this.slider.value = value;
	}
	if (func !== undefined) {
		this.onchangefunc = func;
	}
	var vs = this;
	this.slider.oninput = function () {
		vs.onchange();
	};
	this.setLabel();
};
VarSlider.prototype = {
	getValue: function () { return this.slider.value; },
	setValue: function (x) { this.slider.value = x; },
	onchange: function () {
		this.setLabel();
		this.onchangefunc(Number(this.slider.value));
	},
	onchangefunc: function (a) {}, // 何もしないスタブ。
	setLabel: function () {
		this.valuestring.innerHTML = this.labelstring + this.slider.value;
	}
};
